@@ -19,7 +19,7 @@ Copyright 2008-2011 Heikki Toivonen. All rights reserved.
 version_info = (0, 21, 1)
 version = '.'.join([str(_v) for _v in version_info])
 
-import __m2crypto
+import _m2crypto
 import m2
 import ASN1
 import AuthCookie
@@ -43,10 +43,7 @@ import m2urllib
 # Backwards compatibility.
 urllib2 = m2urllib
 
-import sys
-if sys.version_info >= (2,4):
-    import m2urllib2
-del sys
+import m2urllib2
 
 import ftpslib
 import httpslib
@@ -54,7 +51,7 @@ import m2xmlrpclib
 import threading
 import util
 
-encrypt=1
-decrypt=0
+encrypt = 1
+decrypt = 0
 
-__m2crypto.lib_init()
+_m2crypto.lib_init()
